pub trait ToPositionalField {
// Required method
fn to_positional_field(&self) -> String;
}Expand description
a trait to represent a type that could be converted to a positional field
There is a generic implementation for types that implements Display If you want to customize the output on the file you should implement this trait
Required Methods
fn to_positional_field(&self) -> String
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".